@@ -1,10 +1,9 @@
 # @package      hubzero-submit-distributor
 # @file         JobKill.py
-# @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2020 The Regents of the University of California.
 # @license      http://opensource.org/licenses/MIT MIT
 #
-# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2020 The Regents of the University of California.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +23,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
-# HUBzero is a registered trademark of HUBzero Foundation, LLC.
+# HUBzero is a registered trademark of The Regents of the University of California.
 #
-__version__ = '3.1.3'
+__version__ = '3.6.3'
 
 import sys
 import os
@@ -69,7 +68,7 @@ class JobKill:
       try:
          sys.stdout.write(message)
          sys.stdout.flush()
-      except IOError,err:
+      except IOError:
          pass
 
 
@@ -78,7 +77,7 @@ class JobKill:
       try:
          sys.stderr.write(message)
          sys.stderr.flush()
-      except IOError,err:
+      except IOError:
          pass
 
 
