@@ -1,10 +1,9 @@
 # @package      hubzero-submit-distributor
 # @file         JobStatus.py
-# @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2020 The Regents of the University of California.
 # @license      http://opensource.org/licenses/MIT MIT
 #
-# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2020 The Regents of the University of California.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,9 +23,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
-# HUBzero is a registered trademark of HUBzero Foundation, LLC.
+# HUBzero is a registered trademark of The Regents of the University of California.
 #
-__version__ = '3.2.9'
+__version__ = '3.6.3'
 
 import sys
 import os
@@ -69,7 +68,7 @@ class JobStatus:
       try:
          sys.stdout.write(message)
          sys.stdout.flush()
-      except IOError,err:
+      except IOError:
          pass
 
 
@@ -78,7 +77,7 @@ class JobStatus:
       try:
          sys.stderr.write(message)
          sys.stderr.flush()
-      except IOError,err:
+      except IOError:
          pass
 
 
@@ -145,11 +144,19 @@ class JobStatus:
          except:
             return s.lower()
 
+      try:
+         isinstance("", basestring)
+         def isString(s):
+            return isinstance(s,basestring)
+      except NameError:
+         def isString(s):
+            return isinstance(s,str)
+
       def alphanum_key(s):
          """ Turn a string into a list of string and number chunks.
              "z23a" -> ["z", 23, "a"]
          """
-         if isinstance(s,basestring):
+         if isString(s):
             return [ tryfloat(c) for c in re.split('([0-9.]+)', s) ]
          else:
             return [ tryfloat(s) ]
@@ -176,15 +183,17 @@ class JobStatus:
 
          self.__writeToStdout("%-*s  %12s  %8s  %20s  %s\n" % (maximumRunNameLength,'RunName', \
                                                                'submitRun','Instance','Status','Location'))
-         localJobIds = reportedJobs.keys()
+         localJobIds = list(reportedJobs.keys())
          self.__natsort(localJobIds)
          for localJobId in localJobIds:
             if reportAllIds or (localJobId in self.statusIds):
-               instanceIds = reportedJobs[localJobId].keys()
+               instanceIds = list(reportedJobs[localJobId].keys())
                self.__natsort(instanceIds)
                for instanceId in instanceIds:
                   runName,jobQueue,jobSite,jobStatus,jobStage = reportedJobs[localJobId][instanceId]
-                  if jobQueue != '?':
+                  if   '@' in jobSite:
+                     queueSite = jobSite
+                  elif jobQueue != '?':
                      queueSite = jobQueue + '@' + jobSite
                   else:
                      queueSite = jobSite
