@@ -1,10 +1,9 @@
 # @package      hubzero-submit-distributor
 # @file         RemoteBatchSLURM.py
-# @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2020 The Regents of the University of California.
 # @license      http://opensource.org/licenses/MIT MIT
 #
-# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2020 The Regents of the University of California.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +23,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
-# HUBzero is a registered trademark of HUBzero Foundation, LLC.
+# HUBzero is a registered trademark of The Regents of the University of California.
 #
 import os.path
 import re
@@ -41,6 +40,9 @@ class RemoteBatchSLURM:
                 hubUserName,
                 hubUserId,
                 submitterClass,
+                session,
+                instanceToken,
+                wsJobId,
                 runName,
                 localJobId,
                 instanceId,
@@ -52,6 +54,8 @@ class RemoteBatchSLURM:
                 stdinput,
                 isMultiCoreRequest,
                 siteInfo,
+                toolFilesInfo,
+                dockerImageInfo,
                 submissionScriptsInfo,
                 managerInfo,
                 nNodes,
@@ -63,6 +67,9 @@ class RemoteBatchSLURM:
       self.hubUserName              = hubUserName
       self.hubUserId                = hubUserId
       self.submitterClass           = submitterClass
+      self.session                  = session
+      self.instanceToken            = instanceToken
+      self.wsJobId                  = wsJobId
       self.runName                  = runName
       self.localJobId               = localJobId
       self.instanceId               = instanceId
@@ -99,6 +106,8 @@ class RemoteBatchSLURM:
       else:
          self.account               = ''
       self.submissionScriptCommands = siteInfo['submissionScriptCommands']
+      self.toolFilesInfo            = toolFilesInfo
+      self.dockerImageInfo          = dockerImageInfo
       self.quotaLimit               = quotaLimit
       self.timestampStart           = timeHistoryLogs['timestampStart']
       self.timestampFinish          = timeHistoryLogs['timestampFinish']
@@ -107,6 +116,11 @@ class RemoteBatchSLURM:
       self.nodeFileName = ""
       self.nodeList     = []
 
+      self.toolInputTemplateFileName  = ""
+      self.toolInputTemplate          = ""
+      self.toolOutputTemplateFileName = ""
+      self.toolOutputTemplate         = ""
+
 
    def __buildSerialFile(self):
       rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Batch','SLURM','serial')
@@ -158,6 +172,7 @@ class RemoteBatchSLURM:
       substitutions["REMOTEBATCHACCOUNT"]       = self.account
       substitutions["SUBMISSIONSCRIPTCOMMANDS"] = commandsSLURM
       substitutions["PREMANAGERCOMMANDS"]       = "\n".join(self.preManagerCommands)
+      substitutions["MANAGERCOMMAND"]           = self.managerCommand
       substitutions["POSTMANAGERCOMMANDS"]      = "\n".join(self.postManagerCommands)
       substitutions["HUBUSERNAME"]              = self.hubUserName
       substitutions["HUBUSERID"]                = str(self.hubUserId)
@@ -169,10 +184,88 @@ class RemoteBatchSLURM:
       template = ParameterTemplate(rawSubmissionScript)
       try:
          submissionScript = template.substitute_recur(substitutions)
-      except KeyError,err:
+      except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (err[0])))
-      except TypeError,err:
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+      except TypeError:
+         submissionScript = ""
+         self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
+      else:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            submissionScript = re.sub("(\n)*\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),
+                                           "\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),submissionScript)
+
+      return(submissionScript)
+
+
+   def __buildParallelFile(self):
+      rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Batch','SLURM','parallel')
+
+      partitionSLURM = ""
+      if self.remoteBatchPartition != "":
+         partitionSLURM = self.SUBMISSIONSCRIPTCOMMANDPREFIX + " --partition " + self.remoteBatchPartition
+
+      constraintSLURM = ""
+      if self.remoteBatchConstraints != "":
+         constraintSLURM = self.SUBMISSIONSCRIPTCOMMANDPREFIX + " --constraint " + self.remoteBatchConstraints
+
+      commandsSLURM = ""
+      if self.submissionScriptCommands:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            commandSeparator = "\n%s " % self.SUBMISSIONSCRIPTCOMMANDPREFIX
+            commandsSLURM = self.SUBMISSIONSCRIPTCOMMANDPREFIX + " " + commandSeparator.join(self.submissionScriptCommands)
+         else:
+            commandSeparator = "\n"
+            commandsSLURM = commandSeparator.join(self.submissionScriptCommands)
+
+      environmentExport = ""
+      environmentVars = self.environment.split()
+      for environmentVar in environmentVars:
+         environmentExport += "export " + environmentVar + "\n"
+
+      substitutions = {}
+      if self.stdinput == "":
+         substitutions["STDIN"]                 = '/dev/null'
+      else:
+         substitutions["STDIN"]                 = self.stdinput
+      substitutions["PREMANAGERCOMMANDS"]       = "\n".join(self.preManagerCommands)
+      substitutions["MANAGERCOMMAND"]           = self.managerCommand
+      substitutions["POSTMANAGERCOMMANDS"]      = "\n".join(self.postManagerCommands)
+      substitutions["WALLTIME"]                 = self.wallTime
+      substitutions["PARTITION"]                = partitionSLURM
+      substitutions["CONSTRAINTS"]              = constraintSLURM
+      substitutions["ENVIRONMENT"]              = environmentExport
+      substitutions["EXECUTABLE"]               = self.executable
+      substitutions["ARGUMENTS"]                = self.arguments
+      substitutions["TS_START"]                 = self.timestampStart
+      substitutions["TS_FINISH"]                = self.timestampFinish
+      substitutions["TIME_RESULTS"]             = self.timeResults
+      substitutions["RUNNAME"]                  = self.runName
+      substitutions["JOBID"]                    = self.localJobId
+      substitutions["INSTANCEID"]               = self.instanceId
+      if self.remoteBatchPartitionSize != "":
+         substitutions["NNODES"]                = self.remoteBatchPartitionSize
+      else:
+         substitutions["NNODES"]                = self.nNodes
+      substitutions["PPN"]                      = self.ppn
+      nProcessors = str(int(self.nNodes)*int(self.ppn))
+      substitutions["NPROCESSORS"]              = nProcessors
+      substitutions["REMOTEBATCHACCOUNT"]       = self.account
+      substitutions["SUBMISSIONSCRIPTCOMMANDS"] = commandsSLURM
+      substitutions["HUBUSERNAME"]              = self.hubUserName
+      substitutions["HUBUSERID"]                = str(self.hubUserId)
+      if self.quotaLimit > 0:
+         substitutions["QUOTA"]                 = "ulimit -f " + str(self.quotaLimit)
+      else:
+         substitutions["QUOTA"]                 = ""
+
+      template = ParameterTemplate(rawSubmissionScript)
+      try:
+         submissionScript = template.substitute_recur(substitutions)
+      except KeyError as e:
+         submissionScript = ""
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+      except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
       else:
@@ -242,10 +335,10 @@ class RemoteBatchSLURM:
       template = ParameterTemplate(rawSubmissionScript)
       try:
          submissionScript = template.substitute_recur(substitutions)
-      except KeyError,err:
+      except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (err[0])))
-      except TypeError,err:
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+      except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
       else:
@@ -320,10 +413,10 @@ class RemoteBatchSLURM:
       template = ParameterTemplate(rawSubmissionScript)
       try:
          submissionScript = template.substitute_recur(substitutions)
-      except KeyError,err:
+      except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (err[0])))
-      except TypeError,err:
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+      except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
       else:
@@ -334,8 +427,7 @@ class RemoteBatchSLURM:
       return(submissionScript)
 
 
-   def buildBatchScript(self):
-      batchLogName = ""
+   def getBatchScript(self):
       batchScriptName = "%s_%s.slurm" % (self.localJobId,self.instanceId)
       if self.isMultiCoreRequest:
          if   self.computationMode == 'mpi':
@@ -343,25 +435,55 @@ class RemoteBatchSLURM:
          elif self.computationMode == 'mpiNoFork':
             batchScript = self.__buildMPINoForkFile()
          elif self.computationMode == 'parallel':
-            batchScript = self.__buildSerialFile()
+            batchScript = self.__buildParallelFile()
       else:
          batchScript = self.__buildSerialFile()
       batchScriptExecutable = False
 
-      return(batchLogName,batchScriptName,batchScript,batchScriptExecutable)
+      return(batchScriptName,batchScript,batchScriptExecutable)
+
+
+   def getBatchLog(self):
+      batchLogName = ""
+
+      return(batchLogName)
 
 
    def getBatchNodeList(self):
       return(self.nodeFileName,self.nodeList)
 
 
+   def getBatchToolInputTemplate(self):
+      return(self.toolInputTemplateFileName,self.toolInputTemplate)
+
+
+   def getBatchToolOutputTemplate(self):
+      return(self.toolOutputTemplateFileName,self.toolOutputTemplate)
+
+
+   def getUserDaxExecutables(self):
+      daxExecutables = []
+
+      return(daxExecutables)
+
+
    def getRemoteJobIdNumber(self,
                             remoteJobId):
-      try:
-         remoteJobIdNumber = remoteJobId.split()[-1]
-      except:
-         remoteJobIdNumber = "-1"
-
+      remoteJobIdNumber = -1
+      for piece in reversed(remoteJobId.split()):
+         try:
+            remoteJobIdNumber = int(piece)
+         except:
+            try:
+               remoteJobIdNumber = float(piece)
+            except:
+               pass
+            else:
+               break
+         else:
+            break
+      remoteJobIdNumber = str(remoteJobIdNumber)
+ 
       return(remoteJobIdNumber)
 
 
